@@ -1,11 +1,17 @@
 #![allow(dead_code)]
 
+#[cfg(not(any(feature = "runtime-tokio", feature = "runtime-async-std")))]
+compile_error!("one of 'runtime-async-std' or 'runtime-tokio' features must be enabled");
+
+#[cfg(all(feature = "runtime-tokio", feature = "runtime-async-std"))]
+compile_error!("only one of 'runtime-async-std' or 'runtime-tokio' features must be enabled");
+
 // Modules
 pub use sqlx_core::{arguments, decode, describe, encode, error, pool, row, types};
 
 // Types
 pub use sqlx_core::{
-    Connection, Database, Error, Executor, FromRow, Pool, Query, QueryAs, Result, Row,
+    Connect, Connection, Database, Error, Executor, FromRow, Pool, Query, QueryAs, Result, Row,
 };
 
 // Functions
@@ -20,34 +26,14 @@ pub use sqlx_core::mysql::{self, MySql, MySqlConnection, MySqlPool};
 #[cfg(feature = "postgres")]
 pub use sqlx_core::postgres::{self, PgConnection, PgPool, Postgres};
 
-#[allow(unused_attributes)]
+#[cfg(feature = "macros")]
+#[doc(hidden)]
+pub extern crate sqlx_macros;
+
+#[cfg(feature = "macros")]
 #[macro_export]
 mod macros;
 
-#[cfg(feature = "macros")]
-#[doc(hidden)]
-#[proc_macro_hack::proc_macro_hack(fake_call_site)]
-#[allow(dead_code)]
-pub use sqlx_macros::query as query_;
-
-#[cfg(feature = "macros")]
-#[doc(hidden)]
-#[proc_macro_hack::proc_macro_hack(fake_call_site)]
-#[allow(dead_code)]
-pub use sqlx_macros::query_as as query_as_;
-
-#[cfg(feature = "macros")]
-#[doc(hidden)]
-#[proc_macro_hack::proc_macro_hack(fake_call_site)]
-#[allow(dead_code)]
-pub use sqlx_macros::query_file as query_file_;
-
-#[cfg(feature = "macros")]
-#[doc(hidden)]
-#[proc_macro_hack::proc_macro_hack(fake_call_site)]
-#[allow(dead_code)]
-pub use sqlx_macros::query_file_as as query_file_as_;
-
 // macro support
 #[cfg(feature = "macros")]
 #[doc(hidden)]
